;; Generated package description from system-packages.el  -*- no-byte-compile: t -*-
(define-package "system-packages" "1.0.13" "functions to manage system packages" '((emacs "24.3")) :commit "781f8d40ed35a86a65dda3123506dc810adc10e3" :authors '(("J. Alexander Branham" . "alex.branham@gmail.com")) :maintainer '("J. Alexander Branham" . "alex.branham@gmail.com") :url "https://gitlab.com/jabranham/system-packages")
